@@ -2,10 +2,10 @@
 #
 # Module  : Ontolome.pm
 # Purpose : A Set of ontologies.
-# License : Copyright (c) 2007, 2008 Erick Antezana. All rights reserved.
+# License : Copyright (c) 2007, 2008, 2009, 2010 by Erick Antezana. All rights reserved.
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
-# Contact : Erick Antezana <erick.antezana@gmail.com>
+# Contact : Erick Antezana <erick.antezana -@- gmail.com>
 #
 package OBO::Util::Ontolome;
 
@@ -46,7 +46,7 @@ As implied by its name, this package models the set of ontologies.
 
 =head1 AUTHOR
 
-Erick Antezana, E<lt>erick.antezana@gmail.comE<gt>
+Erick Antezana, E<lt>erick.antezana -@- gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
