@@ -7,6 +7,19 @@
 #           This program is free software; you can redistribute it and/or
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
+#
+###############################################################################
+
+use Carp;
+use strict;
+use warnings;
+use OBO::Parser::OBOParser;
+
+my $my_parser = OBO::Parser::OBOParser->new();
+my $ontology = $my_parser->work(shift(@ARGV));
+$ontology->export(\*STDOUT, "xml");
+
+exit 0;
 
 =head1 NAME
 
@@ -28,13 +41,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
 at your option, any later version of Perl 5 you may have available.
 
-=cut
-
-use Carp;
-use strict;
-use warnings;
-use OBO::Parser::OBOParser;
-
-my $my_parser = OBO::Parser::OBOParser->new();
-my $ontology = $my_parser->work(shift(@ARGV));
-$ontology->export(\*STDOUT, "xml");
\ No newline at end of file
+=cut
\ No newline at end of file
