@@ -8,6 +8,19 @@
 #           modify it under the same terms as Perl itself.
 # Contact : Erick Antezana <erick.antezana -@- gmail.com>
 #
+###############################################################################
+
+use Carp;
+use strict;
+use warnings;
+
+use OBO::Parser::OWLParser;
+
+my $my_parser = OBO::Parser::OWLParser->new();
+my $ontology = $my_parser->work(shift(@ARGV));
+$ontology->export(\*STDOUT, "obo");
+
+exit 0;
 
 =head1 NAME
 
@@ -30,14 +43,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.7 or,
 at your option, any later version of Perl 5 you may have available.
 
-=cut
-
-use Carp;
-use strict;
-use warnings;
-
-use OBO::Parser::OWLParser;
-
-my $my_parser = OBO::Parser::OWLParser->new();
-my $ontology = $my_parser->work(shift(@ARGV));
-$ontology->export(\*STDOUT, "obo");
+=cut
\ No newline at end of file
